pub fn staking_addresses<const NUM_NODES: usize>(
cfg: &TestConfig<NUM_NODES>,
indices: &[usize],
) -> HashSet<Address>Expand description
The L1 accounts of the validators at the given node indices.
pub fn staking_addresses<const NUM_NODES: usize>(
cfg: &TestConfig<NUM_NODES>,
indices: &[usize],
) -> HashSet<Address>The L1 accounts of the validators at the given node indices.